function [J, Jn, W, Wn, S, Sn] = LCMV(B, G, nCov)
%  LCMV BEAMFORMER (SCALAR)
%
% [Input]
%   B : data
%   G : leadfield matrix
%  nCov : noise covariance
% 
% [Output]
%   J  :  currents         Nv* Nt_ana
%   Jn :  normalized currents    Nv*Nt_ana
%   W  :  inverse filter   Nv* Nch
%   Wn :  normalized inverse filter for 
%   S  :  variance    Nv*1
%   Sn :  normalized variance    Nv*1
%
% 2017/09/08 O.Yamashita
% * compatible with trial_average = off
% 2015/08/21 O.Yamashita

if nargin < 5
lam = 0.05;
end

[Nch, Nt, Ntrial] = size(B);
[Nv] = size(G,2);

%
B2d = reshape(B,[Nch,Nt*Ntrial]);
Bave = mean(B,3);

% given G, Cm
Cm = B2d*B2d'/Nt;
iCm = pinv(Cm+ lam*trace(Cm)*eye(Nch));
iCe = pinv(nCov+ lam*trace(nCov)*eye(Nch));

J = zeros(Nv, Nt);
Jn = zeros(Nv, Nt);
W = zeros(Nv, Nch);
Wn = zeros(Nv,Nch);
S = zeros(Nv,1);
Sn = zeros(Nv,1);

fprintf('vertex\n');
for vv = 1 : Nv
    if mod(vv, 1000) == 0,
        fprintf('%d ', vv);
    end
   
    g = G(:,vv);
    
    varm = inv(g'*iCm*g);
    vare = inv(g'*iCe*g);
    
    w = varm*g'*iCm;
    
    J(vv,:) = w * Bave;
    Jn(vv,:) = J(vv,:)/sqrt(vare);
    W(vv,:) = w;
    Wn(vv,:) = w /sqrt(vare);
    S(vv) = varm;  % signal variance
    Sn(vv) = vare; % noise variance
end

fprintf('\n');
