function job_lcmv(lcmv_parm)
% Run LCMV beamformer
%
% 2015/08/25 O.Yamashita

fprintf('--------------------------------------\n');
fprintf('      LCMV beamformer \n');
fprintf('--------------------------------------\n');

%---------------------------------
% Compatibility with bayes_parm 
% Don't modify 
%---------------------------------

lcmv_parm.megfile_baseline  = lcmv_parm.megfile;
lcmv_parm.reduce = 1;
lcmv_parm.Rfilt  = 0; 
lcmv_parm.Tperiod   = lcmv_parm.twin_meg(2) - lcmv_parm.twin_meg(1)+1;
lcmv_parm.Tnext     = lcmv_parm.Tperiod; % Time step for next period

%---------------------
%  Run job
%---------------------
[Cov, sx0] = vb_observation_noise_specification(lcmv_parm);
[B, Ntrials, Nsensors, Tsample, Twindow] = vb_megdata_preparation(lcmv_parm);
[G, ix, ix_ex, W, Norient] = vb_focal_leadfield_preparation(lcmv_parm,1);


[J, Jn, W, Wn, S, Sn] = LCMV(B{1}, G{1}, sx0*Cov{1});


Jest = J;


%------------------------------------------
% Save Curr file 
% Compatibility with .curr.mat of VBMEG
%------------------------------------------
Tstart = Twindow(1);
Tend   = Twindow(end);
Jact   = Jest;
ix_act = ix;
Lact   = Norient;
Varact = Sn(:);

Jbck   = [];
ix_bck = [];
Lbck   = [];

Model.nCov = sx0*Cov{1};
if lcmv_parm.saveifilt
Model.IF   = W;
Model.nIF  = Wn;
end


MEGinfo = vb_load_meg_info(lcmv_parm.megfile);

fprintf('Save current reconstruction result to %s ... \n', lcmv_parm.currfile);
save(lcmv_parm.currfile, 'Jact', 'Jbck', 'ix_act', 'ix_bck', 'Varact',...
    'Tstart', 'Tend', 'MEGinfo', 'lcmv_parm', 'Model');
fprintf('Done ... \n');

end

