function Jest = job_loreta(loreta_parm)
% Run LORETA inverse solution
%
% 2015/08/25 O.Yamashita
% * the first version separated from job_wmn.m

fprintf('--------------------------------------\n');
fprintf('         LORETA solution \n');
fprintf('--------------------------------------\n');

%---------------------------------
% Compatibility with bayes_parm 
% Don't modify 
%---------------------------------

loreta_parm.trial_average = ON;   % only support trial averaged data 
loreta_parm.megfile_baseline  = loreta_parm.megfile;
loreta_parm.reduce = 1;
loreta_parm.Rfilt  = 0; 
loreta_parm.Tperiod   = loreta_parm.twin_meg(2) - loreta_parm.twin_meg(1)+1;
loreta_parm.Tnext     = loreta_parm.Tperiod; % Time step for next period

%---------------------
%  Run job
%---------------------
Cov = vb_observation_noise_specification(loreta_parm);
[B, Ntrials, Nsensors, Tsample, Twindow] = vb_megdata_preparation(loreta_parm);
[G, ix, ix_ex, W, Norient] = vb_focal_leadfield_preparation(loreta_parm,1);  % without leadfield scaling
L = wmn_laplacian_generation(loreta_parm);


fprintf('Calculating LORETA solution ... \n');
if isempty(L)
    error('Empty Laplacian !! Check laplacianfile or laplacian_mode !');
end

[lam,sig, Fval, Jest, IF, Info] = wmn_solution(B{1}, G{1}, inv(Cov{1}), ones(length(ix),1),...
    struct('laplacian',L,'criteria', loreta_parm.criteria, 'Npoints', loreta_parm.npoints, 'flag_plot', loreta_parm.isplot ));  
 
        
% Z value normalized by noise variance
va = size(size(Jest,1),1);
for vv = 1 : size(IF,1)
    va(vv) = sig*IF(vv,:)*Cov{1}*IF(vv,:)';  %   va = sig*diag(F*F');
end
   

%------------------------------------------
% Save Curr file 
% Compatibility with .curr.mat of VBMEG
%------------------------------------------
Tstart = Twindow(1);
Tend   = Twindow(end);
Jact   = Jest;
    
ix_act = ix;
Lact   = Norient;
Varact = va(:);

Jbck   = [];
ix_bck = [];
Lbck   = [];

Model.lam = lam;
Model.sig = sig;
Model.X   = inv(Cov{1});
Model.w   = ones(length(ix),1)
Model.Cov = sig * Cov{1};
Model.fval = Fval;
Model.laplacian = L;
Model.opt_info = Info;
if loreta_parm.saveifilt
Model.IF = IF;
end

MEGinfo = vb_load_meg_info(loreta_parm.megfile);

fprintf('Save current reconstruction result to %s ... \n', loreta_parm.currfile);
save(loreta_parm.currfile, 'Jact', 'Jbck', 'ix_act', 'ix_bck', 'Varact',...
    'Tstart', 'Tend', 'MEGinfo', 'loreta_parm', 'Model');
fprintf('Done ... \n');



    
    
