function Jest = job_mc(mc_parm)
% Run minimum current inverse solution
%
% -- Required
% DAL toolbox
%
% 2015/09/18 O.Y

fprintf('----------------------------------------------\n');
fprintf('   Minimum current solution (Grouped-L1 norm) \n');
fprintf('----------------------------------------------\n');
%---------------------------------
% Compatibility with bayes_parm 
% Don't modify 
%---------------------------------

mc_parm.trial_average = ON;   % only support trial averaged data 
mc_parm.megfile_baseline  = mc_parm.megfile;
mc_parm.reduce = 1;
mc_parm.Rfilt  = 0; 
mc_parm.Tperiod   = mc_parm.twin_meg(2) - mc_parm.twin_meg(1)+1;
mc_parm.Tnext     = mc_parm.Tperiod; % Time step for next period
mc_parm.Rfilt     = 0.5*8e-3/sqrt(log(2)); % FWHM=8mm

%---------------------
%  Run job
%---------------------

Cov = vb_observation_noise_specification(mc_parm);
[B, Ntrials, Nsensors, Tsample, Twindow] = vb_megdata_preparation(mc_parm);
[G, ix, ix_ex, W, Norient] = vb_focal_leadfield_preparation(mc_parm,1); % without leadfield scaling

Q=sqrtm(Cov{1});
BB = Q*B{1};
GG = Q*G{1};

% MN inverse solution
fprintf('Calculating Minimum current solution ... \n');
if isempty(mc_parm.lambda)
    lambda=0.1*max(sqrt(sum((BB'*GG).^2)));
else
    lambda = mc_parm.lambda;
end

[Zest,Info]=dalsqglrow(zeros(size(GG,2),size(BB,2)), GG, BB, lambda);

Jest = W * Zest;

%------------------------------------------
% Save Curr file 
% Compatibility with .curr.mat of VBMEG
%------------------------------------------
Tstart = Twindow(1);
Tend   = Twindow(end);
Jact   = Jest;
ix_act = ix;
Lact   = Norient;
Varact = [];    % J noise variance

Jbck   = [];
ix_bck = [];
Lbck   = [];

Model.opt_info = Info;
if mc_parm.saveifilt
Model.IF = W;
end



MEGinfo = vb_load_meg_info(mc_parm.megfile);

fprintf('Save current reconstruction result to %s ... \n', mc_parm.currfile);
save(mc_parm.currfile, 'Jact', 'Jbck', 'ix_act', 'ix_bck', 'Varact',...
    'Tstart', 'Tend', 'MEGinfo', 'mc_parm', 'Model');
fprintf('Done ... \n');



    

    
    
