function job_pclcmv(lcmv_parm)
% Run post-corrected LCMV beamformer
%
% 2016/08/04 O.Yamashita


%---------------------------------
% Compatibility with bayes_parm 
% Don't modify 
%---------------------------------

lcmv_parm.trial_average = ON;   % only support trial averaged data 
lcmv_parm.megfile_baseline  = lcmv_parm.megfile;
lcmv_parm.reduce = 1;
lcmv_parm.Rfilt  = 0; 
lcmv_parm.Tperiod   = lcmv_parm.twin_meg(2) - lcmv_parm.twin_meg(1)+1;
lcmv_parm.Tnext     = lcmv_parm.Tperiod; % Time step for next period

%---------------------
%  Run job
%---------------------
inner_display_text();
[Cov, sx0] = vb_observation_noise_specification(lcmv_parm);
[B, Ntrials, Nsensors, Tsample, Twindow] = vb_megdata_preparation(lcmv_parm);
[G, ix, ix_ex, W, Norient] = vb_focal_leadfield_preparation(lcmv_parm,1);


[J, Jn, W, Wn, S, Sn] = LCMV(B{1}, G{1}, sx0*Cov{1});


Jest = J;
Zest = Jest ./ repmat(sqrt(Sn(:)), 1,size(Jest,2)); %SAM z-value

%Jest = inner_postcorrection_bbnnls(Zest,G,B);
Jest = inner_postcorrection_l2(Zest,G,B,0.01);

%figure, plot(Jest);

%------------------------------------------
% Save Curr file 
% Compatibility with .curr.mat of VBMEG
%------------------------------------------
Tstart = Twindow(1);
Tend   = Twindow(end);
Jact   = Jest;
ix_act = ix;
Lact   = Norient;
Varact = Sn(:);

Jbck   = [];
ix_bck = [];
Lbck   = [];

Model.nCov = sx0*Cov{1};


MEGinfo = vb_load_meg_info(lcmv_parm.megfile);

fprintf('Save current reconstruction result to %s ... \n', lcmv_parm.currfile);
save(lcmv_parm.currfile, 'Jact', 'Jbck', 'ix_act', 'ix_bck', 'Varact',...
    'Tstart', 'Tend', 'MEGinfo', 'lcmv_parm', 'Model');
fprintf('Done ... \n');

end

%
function inner_display_text()

    fprintf('--------------------------------------\n');
    fprintf('   Post-corrected LCMV beamformer \n');
    fprintf('--------------------------------------\n');
    
 
end


function Jest = inner_postcorrection_bbnnls(Zest,G,B)


bb = B{1}(:);

AA = zeros(size(bb,1), size(G{1},2));
for vv = 1 : size(G{1},2)
    AA(:,vv) = kron(Zest(vv,:)',G{1}(:,vv));
end


AAnorm = sqrt(sum(sum(AA.^2)));
bbnorm = sqrt(sum(bb.^2));

AA = AA / AAnorm;
bb = bb / bbnorm;

% BB-NNLS
x0 = mean(abs(Zest),2)/bbnorm*AAnorm;
opt = solopt;
opt.tolg = 1e-2;
opt.truex=0;
opt.verbose=1;
opt.maxit = 100;
out = bbnnls(AA, bb, x0, opt);


w = out.x*bbnorm/AAnorm;
Jest = Zest .* repmat(w,[1,size(Zest,2)]);

%figure, plot(w); hold on; plot(x0, 'r');

end


function Jest = inner_postcorrection_l2(Zest,G,B,lambda)

bb = B{1};
GG = G{1};

GGG = GG'*GG;
ZZZ = Zest*Zest';

AtAt = GGG.*ZZZ;  % Nv*Nv   diag(Z)*G'*G*diag(Z)
Atbt = sum((GG'*bb) .* Zest,2);  % Nv*Nch    diag(Z)*G'*B


amax = max(AtAt(:));

w = inv(AtAt + amax*eye(size(GG,2))*lambda)*Atbt;

Jest = Zest .* repmat(w,[1,size(Zest,2)]);



end