function Jest = job_sloreta(sloreta_parm)
% Run standardized LORETA (sLORETA) 
%
% see 
% R.D.Pascual-Marqui, Standardized low resolution brain electromagnetic
% tomography (sLORETA) : technical details, Mehtods and Findings in
% Experimental & clinical Pharmacology, 2002, 24D, 5-12
%
%
% 2015/08/27 O.Yamashita


inner_display_text()
%---------------------------------
% Compatibility with bayes_parm 
% Don't modify 
%---------------------------------

sloreta_parm.trial_average = ON;   % only support trial averaged data 
sloreta_parm.megfile_baseline  = sloreta_parm.megfile;
sloreta_parm.reduce = 1;
sloreta_parm.Rfilt  = 0; 
sloreta_parm.Tperiod   = sloreta_parm.twin_meg(2) - sloreta_parm.twin_meg(1)+1;
sloreta_parm.Tnext     = sloreta_parm.Tperiod; % Time step for next period

%---------------------
%  Run job
%---------------------

Cov = vb_observation_noise_specification(sloreta_parm);
[B, Ntrials, Nsensors, Tsample, Twindow] = vb_megdata_preparation(sloreta_parm);
[G, ix, ix_ex, W, Norient] = vb_focal_leadfield_preparation(sloreta_parm,1); % without leadfield scaling


% MN inverse solution
fprintf('Calculating sLORETA solution ... \n');
[lam,sig, Fval, Jest, IF, Info] = wmn_solution(B{1}, G{1}, inv(Cov{1}), ones(length(ix),1),...
    struct('criteria', sloreta_parm.criteria, 'Npoints', sloreta_parm.npoints, 'flag_plot', sloreta_parm.isplot));
        
% diagonal of resolution matrix
va = sum(IF.*G{1}',2);

    
%------------------------------------------
% Save Curr file 
% Compatibility with .curr.mat of VBMEG
%------------------------------------------
Tstart = Twindow(1);
Tend   = Twindow(end);
Jact   = bsxfun(@times, Jest, 1./sqrt(va));
ix_act = ix;
Lact   = Norient;
Varact = [];    % J noise variance

Jbck   = [];
ix_bck = [];
Lbck   = [];

Model.lam = lam;
Model.sig = sig;
Model.X   = inv(Cov{1});
Model.w   = ones(length(ix),1)
Model.Cov = sig * Cov{1};
Model.fval = Fval;
Model.opt_info = Info;

MEGinfo = vb_load_meg_info(sloreta_parm.megfile);

fprintf('Save current reconstruction result to %s ... \n', sloreta_parm.currfile);
save(sloreta_parm.currfile, 'Jact', 'Jbck', 'ix_act', 'ix_bck', 'Varact',...
    'Tstart', 'Tend', 'MEGinfo', 'sloreta_parm', 'Model');
fprintf('Done ... \n');


%
function inner_display_text()

    fprintf('--------------------------------------\n');
    fprintf('     sLORETA solution \n');
    fprintf('--------------------------------------\n');
    

    
    
