function Jest = job_wmn(wmn_parm)
% Run WMN inverse solution
%
% 2017/10/18 O.Yamashita
% * nIF (noise-normalized inverse filter) and rIF (resolution-normalized
% inverse filter) are saved
% 2017/09/14 O.Yamashita
% * IF is saved in Model struct
% 2015/08/25 O.Yamashita 
% * nJest and IF are not saved 
% 2015/08/25 O.Yamashita
% * separate LORETA solution from this routine
% 2015/08/24 OY
% * obsolete opt 
% 2007/01/30 OY
% * Inverse filter is calulated.
% 2006/12/22 OY
% * area_key is considered. 
% 2006/09/26 OY

fprintf('--------------------------------------\n');
fprintf('      L2-Minimum Norm solution \n');
fprintf('--------------------------------------\n');

%---------------------------------
% Compatibility with bayes_parm 
% Don't modify 
%---------------------------------
wmn_parm.trial_average = ON;   % only support trial averaged data 
wmn_parm.megfile_baseline  = wmn_parm.megfile;
wmn_parm.reduce = 1;
wmn_parm.Rfilt  = 0; 
wmn_parm.Tperiod   = wmn_parm.twin_meg(2) - wmn_parm.twin_meg(1)+1;
wmn_parm.Tnext     = wmn_parm.Tperiod; % Time step for next period

%---------------------
%  Run job
%---------------------

Cov = vb_observation_noise_specification(wmn_parm);
[B, Ntrials, Nsensors, Tsample, Twindow] = vb_megdata_preparation(wmn_parm);
[G, ix, ix_ex, W, Norient] = vb_focal_leadfield_preparation(wmn_parm,1); % without leadfield scaling


% MN inverse solution
fprintf('Calculating Minimum Norm solution ... \n');
[lam,sig, Fval, Jest, IF, Info] = wmn_solution(B{1}, G{1}, inv(Cov{1}), ones(length(ix),1),...
    struct('criteria', wmn_parm.criteria, 'Npoints', wmn_parm.npoints, 'flag_plot', wmn_parm.isplot));
        
% Z value normalized by noise variance
va = zeros(size(Jest,1),1);
for vv = 1 : size(IF,1)
    va(vv) = sig*IF(vv,:)*Cov{1}*IF(vv,:)';  %   va = sig*diag(F*F');
end

% resolution kernel (diagonal component)
re = zeros(size(Jest,1),1);
for vv = 1 : size(IF,1)
    re(vv) = IF(vv,:)*G{1}(:,vv);
end
    
%------------------------------------------
% Save Curr file 
% Compatibility with .curr.mat of VBMEG
%------------------------------------------
Tstart = Twindow(1);
Tend   = Twindow(end);
Jact   = Jest;
ix_act = ix;
Lact   = Norient;
Varact = va(:);    % J noise variance
Resact = re(:);

Jbck   = [];
ix_bck = [];
Lbck   = [];

Model.lam = lam;
Model.sig = sig;
Model.X   = inv(Cov{1});
Model.w   = ones(length(ix),1)
Model.Cov = sig * Cov{1};
Model.fval = Fval;
Model.opt_info = Info;
if wmn_parm.saveifilt
Model.IF = IF;
Model.nIF = vb_repmultiply(IF, 1./sqrt(Varact));
Model.rIF = vb_repmultiply(IF, 1./sqrt(re));
end

MEGinfo = vb_load_meg_info(wmn_parm.megfile);

fprintf('Save current reconstruction result to %s ... \n', wmn_parm.currfile);
save(wmn_parm.currfile, 'Jact', 'Jbck', 'ix_act', 'ix_bck', 'Varact','Resact',...
    'Tstart', 'Tend', 'MEGinfo', 'wmn_parm', 'Model');
fprintf('Done ... \n');


    
    
