function [hf1]=plot_current_on_brain(J, brainfile, strtitle, inflate_model, crange, xyz0)
% Plot one current distribution with inside and outside views
% This function is used when one current map is visualized
%
% [Input]
% J : the current distribution to be plotted on the brain (Nv*1 matrix)
% brainfile : the file name of brain file
% [Optional Input]
% strtitle  : string of figure title (Default : [])
% inflate_model : boolean or [0 1]. if inflate_model = 1, the inflated brain is used.
%                 Otherwise the folded brain is used.  (Default : 1)
% crange   : color axis ranges [2,1]. If specified, the common color range
%           is used for all panels. If not specified, MATLAB automated color ranges are
%           used.
% xyz0     : coordinate to be marked on the brain model [N,3].
%           Note that this coordinate must be specified appropriately according to a variable 'inflate_model',
%           since the coordinate of inflate and folded brain differs (see a
%           variable 'Vinflate' and 'V' in brainfile). (Default : [])
%
% 2015/10/06 O.Yamashita

[Nj,Nt]=size(J);
JJ = J;

if nargin < 6
    xyz0 = [];
end

if nargin < 5
    crange = [];
end

if nargin < 4
    inflate_model = 1;
end

if nargin < 3
    strtitle = [];
end

%
angle_Lout = [1,0,0];
angle_Lin = [-1,0,0];



%
plot_parm = vb_set_plot_parm;
plot_parm.brainfile = brainfile;
plot_parm.areafile = '';
plot_parm.index = [];
plot_parm.alpha = 0.6;

% from inside
hf1=figure;

plot_parm.J = JJ;
plot_parm.LRflag = 'L';
subplot(2,2,1);
if inflate_model
    vb_plot_brain_inflate(plot_parm);
else
    vb_plot_brain(plot_parm);
end
view([angle_Lout]);
camlight headlight;
axis equal;
axis off;
hold on
hold on
inner_plot_xyz(xyz0,1,1,brainfile)
if ~isempty(crange), caxis(crange); else, caxis([min(JJ(:)),max(JJ(:))]); end


subplot(2,2,2);
plot_parm.LRflag = 'R';
if inflate_model
    vb_plot_brain_inflate(plot_parm);
else
    vb_plot_brain(plot_parm);
end
view([angle_Lin]);
camlight headlight;
axis equal;
axis off;
hold on
inner_plot_xyz(xyz0,1,0,brainfile)
if ~isempty(crange), caxis(crange); else, caxis([min(JJ(:)),max(JJ(:))]); end



% from outside

plot_parm.LRflag = 'L';
subplot(2,2,3);
if inflate_model
    vb_plot_brain_inflate(plot_parm);
else
    vb_plot_brain(plot_parm);
end
view([angle_Lin]);
camlight headlight;
axis equal;
axis off;
hold on
inner_plot_xyz(xyz0,0,1,brainfile)
if ~isempty(crange), caxis(crange); else, caxis([min(JJ(:)),max(JJ(:))]); end


subplot(2,2,4);
plot_parm.LRflag = 'R';
if inflate_model
    vb_plot_brain_inflate(plot_parm);
else
    vb_plot_brain(plot_parm);
end
view([angle_Lout]);
camlight headlight;
axis equal;
axis off;
hold on
inner_plot_xyz(xyz0,0,0,brainfile)
if ~isempty(crange), caxis(crange); else, caxis([min(JJ(:)),max(JJ(:))]); end
cbar;

suptitle(strtitle);


%
%
%

function inner_plot_xyz(xyz0,inside,left,brainfile) 

 B = load(brainfile);

 if inside 
     for vv = 1 : size(xyz0,1)
             % flag left
             d=sum(bsxfun(@minus,B.V,xyz0(vv,:)).^2,2);
             [dmin, ix] = min(d);
             if ix <= B.F.NdipoleL, flagL=1; else flagL=0; end
    

             if left & flagL  % left, inside
                 scatter3(xyz0(vv,1),xyz0(vv,2),xyz0(vv,3), 30, 'filled');
             elseif  ~left & ~flagL  % right hemisphere, inside
                 scatter3(xyz0(vv,1),xyz0(vv,2),xyz0(vv,3), 30, 'filled');
             end
     end

 else % from outside
        for vv = 1 : size(xyz0,1)
             d=sum(bsxfun(@minus,B.V,xyz0(vv,:)).^2,2);
             [dmin, ix] = min(d);
             if ix <= B.F.NdipoleL, flagL=1; else flagL=0; end
            
             if left & flagL  % left, inside
                 scatter3(xyz0(vv,1),xyz0(vv,2),xyz0(vv,3), 30, 'filled');
             elseif  ~left & ~flagL  % right hemisphere, inside
                 scatter3(xyz0(vv,1),xyz0(vv,2),xyz0(vv,3), 30, 'filled');
             end
           
        end
 end

