function [hf1,hf2]=plot_multiple_currents_on_brain(J, brainfile, strtitle, inflate_model, crange, xyz0)
% Plot multiple maps of current distribution with inside and outside views
%
% For visibility, the number of column of J is recommended to be less than 5.
%
% [Input]
% J : the current distribution to be plotted on the brain (Nj*Nt matrix)
% brainfile : the file name of brain file
% [Optional Input]
% strtitle  : string of figure title (Default : [])
% inflate_model : boolean or [0 1]. if inflate_model = 1, the inflated brain is used.
%                 Otherwise the folded brain is used.  (Default : 1)
% crange   : color axis ranges [2,1]. If specified, the common color range
%           is used for all panels. If not specified, MATLAB automated color ranges are
%           used.
% xyz0     : coordinate to be marked on the brain model [N,3].
%           Note that this coordinate must be specified appropriately according to a variable 'inflate_model',
%           since the coordinate of inflate and folded brain differs (see a
%           variable 'Vinflate' and 'V' in brainfile). (Default : [])
%
% 2015/09/03 O.Yamashita

[Nj,Nt]=size(J);
JJ = J;

if nargin < 6
    xyz0 = [];
end

if nargin < 5
    crange = [];
end

if nargin < 4
    inflate_model = 1;
end

if nargin < 3
    strtitle = ['current'];
end

%
angle_Lout = [1,0,0];
angle_Lin = [-1,0,0];



%
plot_parm = vb_set_plot_parm;
plot_parm.brainfile = brainfile;
plot_parm.areafile = '';
plot_parm.index = [];
plot_parm.alpha = 1;

% from inside
hf1=figure;
for i = 1 : Nt
    plot_parm.J = JJ(:,i);
    plot_parm.LRflag = 'L';
    subplot(Nt,2,2*i-1);
    if inflate_model
        vb_plot_brain_inflate(plot_parm);
    else
        vb_plot_brain(plot_parm);
    end
    view([angle_Lout]);
    camlight headlight;
    axis equal;
    axis off;
    zoom(1.5);
    hold on
    hold on
    inner_plot_xyz(xyz0,1,brainfile)
    if ~isempty(crange), caxis(crange); else, caxis([min(JJ(:,i)),max(JJ(:,i))]); end
   

    subplot(Nt,2,2*i);
    plot_parm.LRflag = 'R';
    if inflate_model
        vb_plot_brain_inflate(plot_parm);
    else
        vb_plot_brain(plot_parm);
    end
    view([angle_Lin]);
    camlight headlight;
    axis equal;
    axis off;
    zoom(1.5);
    hold on
    inner_plot_xyz(xyz0,0,brainfile)
    if ~isempty(crange), caxis(crange); else, caxis([min(JJ(:,i)),max(JJ(:,i))]); end
    cbar;


end
suptitle(strtitle);


% from outside

hf2 = figure;
for i = 1 : Nt
    plot_parm.J = JJ(:,i);
    plot_parm.LRflag = 'LR';
    subplot(Nt,2,2*i-1);
    if inflate_model
        vb_plot_brain_inflate(plot_parm);
    else
        vb_plot_brain(plot_parm);
    end
    view([angle_Lin]);
    camlight headlight;
    axis equal;
    axis off;
    zoom(1.5);
    hold on
    inner_plot_xyz(xyz0,1,brainfile)
    if ~isempty(crange), caxis(crange); else, caxis([min(JJ(:,i)),max(JJ(:,i))]); end


    subplot(Nt,2,2*i);
    plot_parm.LRflag = 'LR';
    if inflate_model
        vb_plot_brain_inflate(plot_parm);
    else
        vb_plot_brain(plot_parm);
    end
    view([angle_Lout]);
    camlight headlight;
    axis equal;
    axis off;
    zoom(1.5);
    hold on
    inner_plot_xyz(xyz0,0,brainfile)
    if ~isempty(crange), caxis(crange); else, caxis([min(JJ(:,i)),max(JJ(:,i))]); end
    cbar;


end
suptitle(strtitle);


%
%
%

function inner_plot_xyz(xyz0,left_hemi,brainfile) 
 
if isempty(xyz0), return; end

B = load(brainfile);
% flag whether xyz0 located in left hemisphere or right hemisphere
flagL = zeros(size(xyz0,1),1);
for vv = 1 : size(xyz0,1)
    d=sum(bsxfun(@minus,B.V,xyz0(vv,:)).^2,2);
    [dmin, ix] = min(d);
    if ix <= B.F.NdipoleL, flagL(vv)=1; else flagL(vv)=0; end
end

ixL=find(flagL);
ixR=find(flagL==0);
if left_hemi
 scatter3(xyz0(ixL,1)*1000,xyz0(ixL,2)*1000,xyz0(ixL,3)*1000, 30, 'filled');
else
 scatter3(xyz0(ixR,1)*1000,xyz0(ixR,2)*1000,xyz0(ixR,3)*1000, 30, 'filled');   
end


 
