function plot_multiple_currents_on_brain_hemi(J, brainfile, LR, strtitle, inflate_model, crange, xyz0)
% Plot multiple maps of current distribution with inside and outside views
% in eigther left or right hemisphere. 
%
% For visibility, the number of column of J is recommended to be less than 5.
%
% [Input]
% J : the current distribution to be plotted on the brain (Nj*Nt matrix)
% brainfile : the file name of brain file
% LR : displayed hemisphere. either of 'L' or 'R'. 
% [Optional Input]
% strtitle  : string of figure title (Default : [])
% inflate_model : boolean or [0 1]. if inflate_model = 1, the inflated brain is used.
%                 Otherwise the folded brain is used.  (Default : 1)
% crange   : color axis ranges [2,1]. If specified, the common color range
%           is used for all panels. If not specified, MATLAB-automated color ranges are
%           used.
% xyz0     : coordinate to be marked on the brain model [N,3].
%           Note that this coordinate must be specified appropriately according to a variable 'inflate_model',
%           since the coordinate of inflate and folded brain differs (see a
%           variable 'Vinflate' and 'V' in brainfile). (Default : [])
%
% 2015/09/03 O.Yamashita
[Nj,Nt]=size(J);
JJ = J;


if nargin < 7
    xyz0 = [];
end


if nargin < 6 | isempty(crange)
    crange = [];
end

if nargin < 5
    inflate_model = 1;
end

if nargin < 4
    strtitle = [];
end


if ~strcmp(LR, 'L') & ~strcmp(LR, 'R'),
    error('LR must be ''L'' or ''R''');
elseif strcmp(LR,'L')
    left = 1;
elseif strcmp(LR,'R')
    left = 0;
end

% 
angle_Lout = [1,0,0];
angle_Lin = [-1,0,0];


  
%
plot_parm = vb_set_plot_parm;
plot_parm.brainfile = brainfile;
plot_parm.areafile = '';
plot_parm.index = [];

for i = 1 : Nt
    plot_parm.J = JJ(:,i);    
    plot_parm.LRflag = LR;
    subplot(Nt,2,2*i-1);
    if inflate_model
        vb_plot_brain_inflate(plot_parm);
    else
        vb_plot_brain(plot_parm);
    end
    view([angle_Lout]);
    camlight headlight;
    zoom(4);
    axis equal;
    axis off;
    hold on
    inner_plot_xyz(xyz0,1,left,brainfile)
    if ~isempty(crange), caxis(crange); else, caxis([min(JJ(:,i)),max(JJ(:,i))]); end
    
    plot_parm.LRflag = LR;
    subplot(Nt,2,2*i);
    if inflate_model
        vb_plot_brain_inflate(plot_parm);
    else
        vb_plot_brain(plot_parm);
    end
    view([angle_Lin]);
    camlight headlight;
    zoom(4);
    axis equal;
    axis off;
    hold on
    inner_plot_xyz(xyz0,0,left,brainfile)

     if ~isempty(crange), caxis(crange); else, caxis([min(JJ(:,i)),max(JJ(:,i))]); end
    cbar;    
end
suptitle(strtitle);

%
%
%
function inner_plot_xyz(xyz0,inside,left,brainfile) 

 B = load(brainfile);

 if inside 
     for vv = 1 : size(xyz0,1)
             % flag left
             d=sum(bsxfun(@minus,B.V,xyz0(vv,:)).^2,2);
             [dmin, ix] = min(d);
             if ix <= B.F.NdipoleL, flagL=1; else flagL=0; end
    

             if left & flagL  % left, inside
                 scatter3(xyz0(vv,1),xyz0(vv,2),xyz0(vv,3), 30, 'filled');
             elseif  ~left & ~flagL  % right hemisphere, inside
                 scatter3(xyz0(vv,1),xyz0(vv,2),xyz0(vv,3), 30, 'filled');
             end
     end

 else % from outside
        for vv = 1 : size(xyz0,1)
             d=sum(bsxfun(@minus,B.V,xyz0(vv,:)).^2,2);
             [dmin, ix] = min(d);
             if ix <= B.F.NdipoleL, flagL=1; else flagL=0; end
            
             if left & flagL  % left, inside
                 scatter3(xyz0(vv,1),xyz0(vv,2),xyz0(vv,3), 30, 'filled');
             elseif  ~left & ~flagL  % right hemisphere, inside
                 scatter3(xyz0(vv,1),xyz0(vv,2),xyz0(vv,3), 30, 'filled');
             end
           
        end
 end





