function bayes_parm = set_bayes_parm(varargin)

parm = finputcheck(varargin, ...
              { 'brainfile'     'string'   []       []; ...
                'megfile'       'string'   []       []; ...
                'basisfile'     'string'   []       [];...
                'currfile'      'string'   []       [];...
                'bayesfile'     'string'   []       [];...
                'twin_meg'      'integer'  []       [];...
                'twin_noise'    'integer'  []       [];...
                'noise_model'   'integer'  [1 2 3]   3;...
                'noise_reg'     'real'     []       0.01;...
                'areafile'      'string'   []       '';...
                'actfile'       'string'   []       '';...
                'area_key'      'string'   []      'Cortex';...
                'act_key'       'string'   []      'Uniform';...
                'patch_norm'    'boolean'  []      ON;...
                'temporal_filter' 'boolean'  []    OFF;...
                'prior_weight'      'real'     []       0.0001;...
                'a0_act'            'real'     []       10;...
                'a0',           'real'     []       1;...
                'reduce'        'real'     []       1;...
                'Ntrain'        'integer'  []      500;...
                'Rfilt'         'real'     []      0.5*8e-3/sqrt(log(2))  ;... % FWHM=8mm
                'trial_average' 'boolean'  []       OFF;...
                });

if isstr(parm), error(parm);end
                
bayes_parm = parm;               


%
% File parameters
%

bayes_parm.basisfile_global ...
    = bayes_parm.basisfile;
bayes_parm.megfile_baseline ...
    = bayes_parm.megfile;

%
% Prior parameters
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bayes_parm.a0 = bayes_parm.a0;
bayes_parm.a0_act = bayes_parm.a0_act;
bayes_parm.prior_weight = bayes_parm.prior_weight;

  

bayes_parm.v0 = 0.01;
bayes_parm.Tv0 = 0;

%
% Time window parameters
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bayes_parm.twin_baseline = bayes_parm.twin_noise;
bayes_parm.Tperiod = bayes_parm.twin_meg(2)-bayes_parm.twin_meg(1)+1;
bayes_parm.Tnext   = bayes_parm.Tperiod;
  

%
% Forward model parameters
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bayes_parm.forward_model = 'focal';
bayes_parm.area_key = 'Cortex';
bayes_parm.area_key_global = 'Cortex';
bayes_parm.reduce_global = bayes_parm.reduce;
bayes_parm.Rfilt_global = bayes_parm.Rfilt;
bayes_parm.expand_spatial_filter = true;
bayes_parm.remove_crossed_area = false;

%
% Extra-dipole parameters
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bayes_parm.extra = [];

%
% Algorithm parameters
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bayes_parm.Npre_train = bayes_parm.Ntrain;
bayes_parm.skip = 100;
bayes_parm.update_sx = true;
bayes_parm.update_v = true;
bayes_parm.Fdmin = 1e-50;
bayes_parm.a_min = 1e-6;
bayes_parm.a_max = 1e6;
bayes_parm.cont_pr = false;

%
% Soft normal constraint parameters (not publicly supported)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bayes_parm.soft_mode = false;
bayes_parm.variance_orientation = false;
bayes_parm.var_max = 1/sqrt(2);
bayes_parm.tan_var = 1.0;
bayes_parm.cosval = cos(pi);