%  test script for various inverse solution 
% 
% * single time window, 
% * single run leadfield matrix
% * single orientation for each vertex

clear 
close all

%---------- EDIT HERE : SET OUTPUT DIRECTORY --------------%
outputdir = 'RESULTS/';
if exist(outputdir, 'dir') == 0, eval(['mkdir ' outputdir]); end
%----------------------------------------------------------%

rdir = '../TESTDATA/';
brainfile = [rdir 'sbj_test.brain.mat' ];
megfile   = [rdir 'sbj_test_HPF_LPF_BC-TriggerLR.meg.mat' ];
basisfile = [rdir 'sbj_test_HPF_LPF_BC-TriggerLR.basis.mat'];
twin_meg  = [501 750]; % Time window for analysis
twin_noise  = [1, 500];	% specify sample index 
areafile  = [rdir 'sbj_test.area.mat'  ];
actfile   = [rdir 'sbj_test.act.mat'   ];


% MN
wmn_parm = set_wmn_parm('brainfile',brainfile,...
    'megfile',megfile,...
    'basisfile',basisfile,...
    'areafile',areafile,...
    'actfile', actfile,...
    'twin_meg', twin_meg,...
    'twin_noise',twin_noise,...
    'currfile', sprintf('%smn.curr.mat',outputdir));
job_wmn(wmn_parm);


% % LORETA
lor_parm = set_loreta_parm('brainfile',brainfile,...
    'megfile',megfile,...
    'basisfile',basisfile,...
    'laplacianfile', sprintf('%slaplacian.mat',outputdir),...
    'areafile',areafile,...
    'actfile', actfile,...
    'twin_meg', twin_meg,...
    'twin_noise',twin_noise,...
    'currfile', sprintf('%sloreta.curr.mat',outputdir));
job_loreta(lor_parm);


% sLORETA
slor_parm = set_sloreta_parm('brainfile',brainfile,...
    'megfile',megfile,...
    'basisfile',basisfile,...
    'areafile',areafile,...
    'actfile', actfile,...
    'twin_meg', twin_meg,...
    'twin_noise',twin_noise,...
    'currfile', sprintf('%ssloreta.curr.mat',outputdir));
job_sloreta(slor_parm);

% LCMV
lcmv_parm = set_lcmv_parm('brainfile',brainfile,...
    'megfile',megfile,...
    'basisfile',basisfile,...
    'areafile',areafile,...
    'actfile', actfile,...
    'twin_meg', twin_meg,...
    'twin_noise',twin_noise,...
    'currfile', sprintf('%slcmv.curr.mat',outputdir));
job_lcmv(lcmv_parm);

% Minimum current (L1-norm)
mc_parm = set_mc_parm('brainfile',brainfile,...
    'megfile',megfile,...
    'basisfile',basisfile,...
    'areafile',areafile,...
    'actfile', actfile,...
    'twin_meg', twin_meg,...
    'twin_noise',twin_noise,...
    'currfile', sprintf('%smc.curr.mat',outputdir));
job_mc(mc_parm);

% vbmeg fMRI 
proj_root = './';
bayes_parm = set_bayes_parm('brainfile',brainfile,...
    'megfile',megfile,...
    'basisfile',basisfile,...
    'areafile',areafile,...
    'actfile', actfile,...
    'twin_meg', twin_meg,...
    'twin_noise',twin_noise,...
    'bayesfile', sprintf('%svbfmri.bayes.mat',outputdir),...
    'currfile',  sprintf('%svbfmri.curr.mat',outputdir),...
    'act_key', 'LR',...
    'prior_weight', 0.5,...
    'reduce', 0.25)
vb_job_vb(proj_root,bayes_parm);
curr_parm = struct('bayesfile', bayes_parm.bayesfile, 'currfile', bayes_parm.currfile);
vb_job_current(proj_root, curr_parm);

% vbmeg + mn
tmpactfile  = sprintf('%stmp.act.mat',outputdir);
inicurrfile = sprintf('%smn.curr.mat',outputdir);
MN=load(inicurrfile);
Jact = MN.Jact;
Pow=mean(MN.Jact.^2,2);
vb_add_act(tmpactfile,struct('xxP',Pow,'key','MN','comment','MN power'), '0000000',OFF);

proj_root = './';
bayes_parm = set_bayes_parm('brainfile',brainfile,...
    'megfile',megfile,...
    'basisfile',basisfile,...
    'areafile',areafile,...
    'actfile', tmpactfile,...
    'twin_meg', twin_meg,...
    'twin_noise',twin_noise,...
    'bayesfile', sprintf('%svbmn.bayes.mat',outputdir),...
    'currfile',  sprintf('%svbmn.curr.mat',outputdir),...
    'act_key', 'MN',...
    'prior_weight', 0.05,...
    'reduce', 0.25)
vb_job_vb(proj_root,bayes_parm);
curr_parm = struct('bayesfile', bayes_parm.bayesfile, 'currfile', bayes_parm.currfile);
vb_job_current(proj_root, curr_parm);







