function [Ev] = wmn_calc_evidence(BB, G, sx, ax, Nt, S)
% calculate evidence p(B) of wmn solution.
% p(B|J;sx) ~ N(GB, sx*S)
% P(J;A,sx) ~ N(0, sx*A)
% i.e.   1/(2sx)*{(B-GJ)'S^{-1}(B-GJ)+J'A^{-1}J}
%
% [Ev] = wmn_calc_evidence(BB, G, sx, ax, Nt, S)
%
% -- input
% sx : "variance" of observation noise 1*1 (scaling only)
% ax : "variance" of prior currents Nj*1 (diagonal component only)
% Nt : Number of samples in time 
% -- optional
% S  : "covariance" of observation noise Nch*Nch 

if nargin < 5
    help wmn_calc_evidence
end

[Nch,Nj]= size(G);

if nargin < 6
    S = eye(Nch);
end

Ax  = repmat(ax , [1 Nch]); % variance
GGA    = G*(Ax.*G');
SB_inv = inv( GGA + S);		

%% evidence calculation (2*log(evidence))
Et = -sum(diag(SB_inv*BB))/sx
E1 = -Nch*Nt*log(sx);
E2 = Nt*log(det(SB_inv));
E3 = -Nch*Nt*log(2*pi);     
%E4 =  -Neparm*log(Ntt)      % penalty for model complexisity
Ev = Et+E1+E2+E3;

Ev = (E1+E2)/2


