function L = wmn_laplacian_generation(wmn_parm)
%  Generate Laplacian matrix from the vertices information of the nearest neighbor
%
%  Please refer to 
%   T.F.Oostendorp et.el., J. Computational Physics, 80, 331-343, 1989 
%  in details.
% 
%  2006/09/13 OY

% variables of wmn_parm used in this function
struct2vars(wmn_parm,{'brainfile', 'laplacianfile', 'laplacian_mode', 'cosval'})

switch laplacian_mode
    case 'skip',
         fprintf('Laplacian calculation skipped ... \n');
         L = [];
         return;
         
    case 'load',
        fprintf('Load Laplacian matrix from %s ... \n', laplacianfile);
        load(laplacianfile, 'L');
        return;
        
    case {'save','calc'}, 

        tic;
        
        load(brainfile, 'xxD', 'xxF', 'xx');

        Nj = length(xxD);
        NaveNN = 6; % Number of averaged Nearest Neighbor

        L = speye(Nj);
        %ANGLE = [];
        for i = 1 : Nj

            nnn = length(xxD{i}); % Number of the Nearest Neighbor
            if nnn < 6
                nnn = NaveNN;
            end

            % value assosiated with i th vertex
            dist = xxD{i};
            invdist = 1./xxD{i};
            ix_ne = xxF{i};

            hi = mean(dist);         % average distance
            invhi = mean(invdist);  % average of inverse distance

            % angle constraints
            cos_angle = xx(i,:) * xx(xxF{i},:)';
            ix = find(cos_angle > cosval);
            ix_ne = ix_ne(ix);

            L(i,i) = - 4/hi * invhi;  % self
            L(i, ix_ne) = 4/(hi*nnn) .* invdist(ix);  % neighbour

            %   ANGLE = [ANGLE cos_angle];
        end
        
        fprintf('Calculation done ... \n');
        toc;

        if strcmp(laplacian_mode, 'save'),
            fprintf('Save Laplacian matrix to %s ... \n', laplacianfile);
            save(laplacianfile, 'L', 'wmn_parm');
            fprintf('Done ...\n');
        end
    otherwise,
        error('No such mode !!');
end
